@@ -71,10 +71,10 @@ impl LuaError {
 }
 
 lazy_static::lazy_static! {
-	pub(crate) static ref LUA_SHARED: LuaShared = LuaShared::import();
+	pub static ref LUA_SHARED: LuaShared = LuaShared::import();
 }
 
-pub(crate) struct LuaShared {
+pub struct LuaShared {
 	pub lual_newstate: Symbol<'static, unsafe extern "C-unwind" fn() -> LuaState>,
 	pub lual_openlibs: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState)>,
 	pub lual_loadfile: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, path: LuaString) -> i32>,
@@ -124,6 +124,7 @@ pub(crate) struct LuaShared {
 	pub lua_getinfo: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, what: LuaString, ar: *mut LuaDebug) -> i32>,
 	pub lua_getstack: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, level: i32, ar: *mut LuaDebug) -> i32>,
 	pub lua_next: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> i32>,
+	pub lua_topointer: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> *const c_void>,
 }
 unsafe impl Sync for LuaShared {}
 impl LuaShared {
@@ -188,6 +189,7 @@ impl LuaShared {
 				lua_getinfo: find_symbol!("lua_getinfo"),
 				lua_getstack: find_symbol!("lua_getstack"),
 				lua_next: find_symbol!("lua_next"),
+				lua_topointer: find_symbol!("lua_topointer")
 			}
 		}
 	}
