@@ -381,13 +381,27 @@ impl LuaState {
 		(LUA_SHARED.lua_next)(*self, index)
 	}
 
+	#[inline]
+	pub unsafe fn to_pointer(&self, index: i32) -> *const c_void {
+		(LUA_SHARED.lua_topointer)(*self, index)
+	}
+
 	pub unsafe fn error<S: AsRef<str>>(&self, msg: S) -> ! {
 		self.push_string(msg.as_ref());
 		(LUA_SHARED.lua_error)(*self);
 		unreachable!()
 	}
 
-	pub unsafe fn debug_get_info(&self, what: LuaString) -> Option<LuaDebug> {
+	pub unsafe fn debug_getinfo_from_ar(&self, ar: &mut LuaDebug, what: LuaString) -> Result<(), ()> {
+		if (LUA_SHARED.lua_getinfo)(*self, what, ar as *mut LuaDebug) != 0 {
+			Ok(())
+		} else {
+			Err(())
+		}
+	}
+
+	/// `what` should start with `>` and pop a function off the stack
+	pub unsafe fn debug_getinfo_from_stack(&self, what: LuaString) -> Option<LuaDebug> {
 		let mut ar = MaybeUninit::uninit();
 		if (LUA_SHARED.lua_getinfo)(*self, what, ar.as_mut_ptr()) != 0 {
 			Some(ar.assume_init())
@@ -396,7 +410,16 @@ impl LuaState {
 		}
 	}
 
-	pub unsafe fn debug_get_invocation_info(&self, level: i32, what: LuaString) -> Option<LuaDebug> {
+	pub unsafe fn get_stack_at(&self, level: i32) -> Option<LuaDebug> {
+		let mut ar = MaybeUninit::uninit();
+		if (LUA_SHARED.lua_getstack)(*self, level, ar.as_mut_ptr()) != 0 {
+			Some(ar.assume_init())
+		} else {
+			None
+		}
+	}
+
+	pub unsafe fn debug_getinfo_at(&self, level: i32, what: LuaString) -> Option<LuaDebug> {
 		let mut ar = MaybeUninit::uninit();
 		if (LUA_SHARED.lua_getstack)(*self, level, ar.as_mut_ptr()) != 0 {
 			if (LUA_SHARED.lua_getinfo)(*self, what, ar.as_mut_ptr()) != 0 {
